@@ -5,13 +5,22 @@ from .widgets import (
     Container,
     DateEdit,
     DateTimeEdit,
+    EmptyWidget,
+    FloatSlider,
     FloatSpinBox,
+    Image,
     Label,
     LineEdit,
+    LiteralEvalLineEdit,
+    MainWindow,
+    ProgressBar,
     PushButton,
     RadioButton,
+    RadioButtons,
+    Select,
     Slider,
     SpinBox,
+    Table,
     TextEdit,
     TimeEdit,
     get_text_width,
@@ -25,13 +34,22 @@ __all__ = [
     "Container",
     "DateEdit",
     "DateTimeEdit",
+    "EmptyWidget",
+    "FloatSlider",
     "FloatSpinBox",
+    "Image",
     "Label",
     "LineEdit",
+    "LiteralEvalLineEdit",
+    "MainWindow",
+    "ProgressBar",
     "PushButton",
     "RadioButton",
+    "RadioButtons",
+    "Select",
     "Slider",
     "SpinBox",
+    "Table",
     "TextEdit",
     "TimeEdit",
     "get_text_width",
