@@ -24,6 +24,7 @@ from ._concrete import (
     FloatSpinBox,
     Label,
     LineEdit,
+    ListEdit,
     LiteralEvalLineEdit,
     LogSlider,
     MainWindow,
@@ -38,6 +39,7 @@ from ._concrete import (
     SpinBox,
     TextEdit,
     TimeEdit,
+    TupleEdit,
 )
 from ._dialogs import show_file_dialog
 from ._function_gui import FunctionGui, MainFunctionGui
@@ -77,6 +79,7 @@ __all__ = [
     "Image",
     "Label",
     "LineEdit",
+    "ListEdit",
     "LiteralEvalLineEdit",
     "LogSlider",
     "MainFunctionGui",
@@ -93,6 +96,7 @@ __all__ = [
     "Table",
     "TextEdit",
     "TimeEdit",
+    "TupleEdit",
     "Widget",
     "show_file_dialog",
 ]
