@@ -22,9 +22,10 @@ from typing import (
     cast,
 )
 
+from psygnal import Signal
+
 from magicgui._type_wrapper import resolve_forward_refs
 from magicgui.application import AppRef
-from magicgui.events import Signal
 from magicgui.signature import MagicSignature, magic_signature
 from magicgui.widgets import Container, MainWindow, ProgressBar, PushButton
 from magicgui.widgets._bases.value_widget import ValueWidget
